summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMichael I. Bushnell <mib@gnu.org>1995-10-30 21:00:48 +0000
committerMichael I. Bushnell <mib@gnu.org>1995-10-30 21:00:48 +0000
commit8b51467cf274617e69493cad51dee8f09b41066c (patch)
tree718ae730f6e114318914ae93df29843791587cde
parent396031151da95eb1b7724d5c36bbb08a54af0ca8 (diff)
(enum file_storage_class): Add STORAGE_TASK. Drop all the MUTATED
bits. (STORAGE_MUTATED): New flag.
-rw-r--r--hurd/hurd_types.h22
1 files changed, 8 insertions, 14 deletions
diff --git a/hurd/hurd_types.h b/hurd/hurd_types.h
index 385c2585..ef9f796b 100644
--- a/hurd/hurd_types.h
+++ b/hurd/hurd_types.h
@@ -148,18 +148,20 @@ enum term_bottom_type
TERM_ON_MASTERPTY,
};
+/* Flags for file_get_storage_info. */
+#define STORAGE_MUTATED 0x00000001 /* data as stored is munged from file */
+
/* Classes for file_get_storage_info. */
enum file_storage_class
{
STORAGE_OTHER,
STORAGE_DEVICE,
- STORAGE_DEVICE_MUTATED,
STORAGE_HURD_FILE,
- STORAGE_HURD_FILE_MUTATED,
STORAGE_NETWORK,
STORAGE_MEMORY,
- STORAGE_MEMORY_MUTATED,
+ STORAGE_TASK,
};
+
/* STORAGE_DEVICE implies that:
STORAGE_PORT, if non-null, is a device_t holding the data.
@@ -178,10 +180,6 @@ enum file_storage_class
STORAGE_MISC may contain additional type specific information.
*/
-/* STORAGE_DEVICE_MUTATED is like STORAGE_DEVICE, except that the data
- as written to the device may be different (because of compression,
- for example) than the contents of the file. */
-
/* STORAGE_HURD_FILE implies that:
STORAGE_PORT, if non-null, is a file_t holding the data.
@@ -198,15 +196,11 @@ enum file_storage_class
STORAGE_MISC may contain additional type-specific information.
*/
-/* STORAGE_HURD_FILE_MUTATED is like STORAGE_HURD_FILE, except that the
- data as written to STORAGE_PORT/NAME may be different (because of
- compression, for example) than the contents of the file. */
-
-/* STORAGE_MEMORY is like STORAGE_HURD_FILE, except that the data is found
+/* STORAGE_TASK is like STORAGE_HURD_FILE, except that the data is found
in the virtual address space of the task identified by STORAGE_PORT.
-/* STORAGE_MEMORY_MUTATED is like STORAGE_MEMORY, except that the data
- may be mutated in storage. */
+/* STORAGE_MEMORY is similar, except the data is found in the memory
+ object identified by STORAGE_PORT. */
/* STORAGE_NETWORK means that the file is stored elsewhere on the
network; all the remaining fields contan type-specific information. */